@@ -12,12 +12,17 @@ pub mod v1 {
         ///
         /// This is using the stable v1::CustomResourceDefinitions (present in kubernetes >= 1.16)
         fn crd() -> super::apiexts::v1::CustomResourceDefinition;
+        /// Helper to return the name of this `CustomResourceDefinition` in kubernetes.
+        ///
+        /// This is not the name of an _instance_ of this custom resource but the `CustomResourceDefinition` object itself.
+        fn crd_name() -> &'static str;
         /// Helper to generate the api information type for use with the dynamic `Api`
         fn api_resource() -> crate::discovery::ApiResource;
     }
 }
 
 /// Types for legacy v1beta1 CustomResourceDefinitions
+#[cfg(feature = "deprecated-crd-v1beta1")]
 pub mod v1beta1 {
     /// Extension trait that will be implemented by kube-derive for legacy v1beta1::CustomResourceDefinitions
     ///
@@ -27,6 +32,10 @@ pub mod v1beta1 {
         ///
         /// This is using v1beta1::CustomResourceDefinitions (which will be removed in kubernetes 1.22)
         fn crd() -> super::apiexts::v1beta1::CustomResourceDefinition;
+        /// Helper to return the name of this `CustomResourceDefinition` in kubernetes.
+        ///
+        /// This is not the name of an _instance_ of this custom resource but the `CustomResourceDefinition` object itself.
+        fn crd_name() -> &'static str;
         /// Helper to generate the api information type for use with the dynamic `Api`
         fn api_resource() -> crate::discovery::ApiResource;
     }
